==> phpaga-0.3.tar.bz2: phpaga-0.3/htdocs/users.php <==
<?php
/**
 * phpaga
 *
 * Users
 *
 * This is the user management interface (list and search).
 *
 * @author Florian Lanthaler <florian@phpaga.net>
 * @version $Id: users.php 726 2006-08-05 22:34:30Z florian $
 *
 * Copyright (c) 2002, Florian Lanthaler <florian@phpaga.net>
 *
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *    * Redistributions of source code must retain the above copyright
 *      notice, this list of conditions and the following disclaimer.
 *
 *    * Redistributions in binary form must reproduce the above copyright
 *      notice, this list of conditions and the following disclaimer in
 *      the documentation and/or other materials provided with the
 *      distribution.
 *
 *    * Neither the name of Florian Lanthaler nor the names of his
 *      contributors may be used to endorse or promote products derived
 *      from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS
 * IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED
 * TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
 * PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER
 * OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
 * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
 * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

include_once("./config.php");
phpaga_user_pageperm(PHPAGA_PERM_MANAGE_SYSSETTINGS);

$userInfo = array();
$usr_id = 0;
$search_args = "";
$rows = "";
$browse = "";
$action = ACTION_NONE;
$result_usrdel = PHPAGA_ERR_NONE;

phpaga_header(array("menuitem" => "administration"));

if (isset($_REQUEST["action"]) && is_numeric($_REQUEST["action"]))
{
    $action = $_REQUEST["action"];
}

if (isset($_REQUEST["id"]) && is_numeric($_REQUEST["id"]))
{
    $usr_id = $_REQUEST["id"];
}

switch($action)
{
    case ACTION_REMOVE:

        if (is_numeric($usr_id) && ($usr_id > 0))
            $result_usrdel = phpaga_user_delete($usr_id);

        break;

    default:
        break;
}

/* get offset (where to start with person list) */
if (isset($_REQUEST["offset"]) && is_numeric($_REQUEST["offset"]))
{
    $offset = $_REQUEST["offset"];
}
else
{
    $offset = 0;
}

/* get search criteria */

/* login name */
if (isset($_REQUEST["usr_login"]) && strlen($_REQUEST["usr_login"]))
{
    $userInfo["usr_login"] = rawurldecode($_REQUEST["usr_login"]);
}
else
{
    $userInfo["usr_login"] = "";
}

/* person's last name */
if (isset($_REQUEST["pe_lastname"]) && strlen($_REQUEST["pe_lastname"]))
{
    $userInfo["pe_lastname"] = rawurldecode($_REQUEST["pe_lastname"]);
}
else
{
    $userInfo["pe_lastname"] = "";
}

/* build search args to be passed to url */
foreach ($userInfo as $key =>$value)
{
    if (isset ($value) && ($value != ""))
        $search_args .= "&$key=".rawurlencode ($value);
}

$location = $_SERVER["PHP_SELF"]."?$search_args";

$result = phpaga_user_search($rows, $userInfo, $offset,
                             PHPAGA_RECORDS_PERPAGE);

if (($result != PHPAGA_ERR_NONE) && ($result != PHPAGA_ERR_DB_NO_ROWS))
{
    phpaga_error ($result);
}

if ($result_usrdel != PHPAGA_ERR_NONE)
{
    phpaga_error($result_usrdel);
}

$users_tpl = new psmarty;

$users_tpl->assign("FORM_ACTION", basename($_SERVER["PHP_SELF"]));
$users_tpl->assign("s_userInfo", $userInfo);
$users_tpl->assign("rows", $rows);

$users_tpl->display("users.tpl.html");

phpaga_footer();

?>

==> phpaga-0.6.tar.bz2: phpaga-0.6/htdocs/users.php <==
<?php
/**
 * phpaga
 *
 * Users
 *
 * This is the user management interface (list and search).
 *
 * @author Florian Lanthaler <florian@phpaga.net>
 * @version $Id$
 *
 * Copyright (c) 2002, Florian Lanthaler <florian@phpaga.net>
 *
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *    * Redistributions of source code must retain the above copyright
 *      notice, this list of conditions and the following disclaimer.
 *
 *    * Redistributions in binary form must reproduce the above copyright
 *      notice, this list of conditions and the following disclaimer in
 *      the documentation and/or other materials provided with the
 *      distribution.
 *
 *    * Neither the name of Florian Lanthaler nor the names of his
 *      contributors may be used to endorse or promote products derived
 *      from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS
 * IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED
 * TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
 * PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER
 * OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
 * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
 * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

include_once('./config.php');
phpaga_user_pageperm(PHPAGA_PERM_MANAGE_SYSSETTINGS);

$userInfo = array('pe_lastname' => null,
                  'usr_login' => null);
$rows = null;

phpaga_header(array('menuitem' => 'administration'));

if (isset($REQUEST_DATA['usr_login']) && strlen($REQUEST_DATA['usr_login']))
    $userInfo['usr_login'] = rawurldecode($REQUEST_DATA['usr_login']);

if (isset($REQUEST_DATA['pe_lastname']) && strlen($REQUEST_DATA['pe_lastname']))
    $userInfo['pe_lastname'] = rawurldecode($REQUEST_DATA['pe_lastname']);

$rows = phpaga_user_search($userInfo);
if (PhPagaError::isError($rows))
    $rows->printMessage();

$tpl = new psmarty;
$tpl->assign('FORM_ACTION', basename($_SERVER['PHP_SELF']));
$tpl->assign('s_userInfo', $userInfo);
$tpl->assign('rows', $rows);
$tpl->display('users.tpl.html');

phpaga_footer();

?>
